Crate langcodec_cli

Crate langcodec_cli 

CLI library for testing purposes

Re-exports

pub use annotate::AnnotateOptions;
pub use annotate::run_annotate_command;
pub use formats::CustomFormat;
pub use formats::parse_custom_format;
pub use tolgee::TolgeePullOptions;
pub use tolgee::TolgeePushOptions;
pub use tolgee::run_tolgee_pull_command;
pub use tolgee::run_tolgee_push_command;
pub use transformers::custom_format_to_resource;
pub use translate::TranslateOptions;
pub use translate::run_translate_command;
pub use tui::UiMode;

Modules

ai
annotate
config
formats
merge
tolgee
transformers
translate
tui
ui
validation

Structs

Codec
Represents a collection of localized resources and provides methods to read, write, cache, and load these resources.